==> breeze_website_builder_6.5.0.tar.gz: manage/plugins/lang/gallery/la.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "Morbi Manage Lightbox Gallary");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "Manage Gallery");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "Full Width-Size Image");
define('MANAGE_GALLERY_FULL_HEIGHT', "Full-Size Image Height");
define('MANAGE_GALLERY_THUMB_WIDTH', "Thumbnail Width Image");
define('MANAGE_GALLERY_THUMB_HEIGHT', "Thumbnail Image Height");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "Ut Ratio Thumb Aspect");
define('MANAGE_GALLERY_SHOW_TITLES', "Show Titles");
define('MANAGE_GALLERY_DISABLE_SORT', "Disable Sort");
define('MANAGE_GALLERY_DELETE_IMAGE', "Delete Image");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "Save Sort order");
define('MANAGE_GALLERY_PUBLISH_MSG', "Click &quot;Update ut auditum <br /> uploaded simulacra vestra.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "All resized obitusque salvati fuerint.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "Erat, nec cura peculi error resizing imagines occasus.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "Imago tua (s) uploaded fuerit.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "Erat discas imaginem errorem (s).");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "Fasciculi fasciculos quaeritis non est imago.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "Fasciculi nimium est fasciculos conaris.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "Titulus est, salvabitur.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "Visne tu imaginem delere");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "Imago deleta est.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "Deletis imago fuit error.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "Salvis parametri et imagines resizing Sede ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "Uploading, please wait ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "Talem ordinem non servatum. Vis ut salvaret genus?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "Quodam ordine salvari imago.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "Nisi quaedam imago fuit error.");
?>

==> breeze_website_builder_6.6.18.tar.gz: manage/plugins/lang/gallery/la.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "Morbi Manage Lightbox Gallary");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "Manage Gallery");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "Full Width-Size Image");
define('MANAGE_GALLERY_FULL_HEIGHT', "Full-Size Image Height");
define('MANAGE_GALLERY_THUMB_WIDTH', "Thumbnail Width Image");
define('MANAGE_GALLERY_THUMB_HEIGHT', "Thumbnail Image Height");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "Ut Ratio Thumb Aspect");
define('MANAGE_GALLERY_SHOW_TITLES', "Show Titles");
define('MANAGE_GALLERY_DISABLE_SORT', "Disable Sort");
define('MANAGE_GALLERY_DELETE_IMAGE', "Delete Image");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "Save Sort order");
define('MANAGE_GALLERY_PUBLISH_MSG', "Click &quot;Update ut auditum <br /> uploaded simulacra vestra.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "All resized obitusque salvati fuerint.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "Erat, nec cura peculi error resizing imagines occasus.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "Imago tua (s) uploaded fuerit.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "Erat discas imaginem errorem (s).");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "Fasciculi fasciculos quaeritis non est imago.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "Fasciculi nimium est fasciculos conaris.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "Titulus est, salvabitur.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "Visne tu imaginem delere");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "Imago deleta est.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "Deletis imago fuit error.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "Salvis parametri et imagines resizing Sede ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "Uploading, please wait ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "Talem ordinem non servatum. Vis ut salvaret genus?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "Quodam ordine salvari imago.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "Nisi quaedam imago fuit error.");
define('MANAGE_GALLERY_UPLOAD_BIGGER_THAN_ALLOWED_ERR', "Upload lima quod vos es trying ut esse maior quam est &#39;upload_max_filesize&#39; vel &#39;post_max_size, PHP occasus. Hi fines contact vestra crescat ratio ut administrator.");
?>
